rfc3161
=======

A simple client library for cryptographic timestamping service implement the
protocol from RFC3161.

Authors
=======

Benjamin Dauvergne <bdauvergne@entrouvert.com>
Michael Gebetsroither <michael@mgeb.org>
